@@ -12,17 +12,13 @@ def log_group(config) -> Optional[ResourceOutput]:
     sub_config = config.get("config", {})
     log_group_config = sub_config.get("codebuild", {}).get("log_group", {})
 
-    if not log_group_config.get("enabled", False) or not log_group_config.get(
-        "create", True
-    ):
+    if not log_group_config.get("enabled") or not log_group_config.get("create"):
         return None
 
     resource_properties = {
-        "KmsKeyId": parse_value(
-            "${KmsKeyArn}", KmsKeyArn=sub_config.get("kms_key_arn", "AWS::NoValue")
-        ),
+        "KmsKeyId": parse_value("${KmsKeyArn}", KmsKeyArn=sub_config["kms_key_arn"]),
         "LogGroupName": parse_value(
-            "${LogGroupName}", LogGroupName=log_group_config.get("name")
+            "${LogGroupName}", LogGroupName=log_group_config.get("name", "AWS::NoValue")
         ),
         "RetentionInDays": parse_value(
             "${Retention}", Retention=log_group_config.get("retention", "AWS::NoValue")
